.. _contributors-team-meetings-roadmap-calendar:

Team Meetings, Road Map and Calendar
====================================

Many of the lead Jupyter Server developers meet weekly over Zoom. These meetings are open to everyone.

To see when the next meeting is happening, watch this Github issue:

https://github.com/jupyter/jupyter_server/issues/126

Also check out Jupyter Server's roadmap where we track future plans for Jupyter Server:

https://github.com/jupyter/jupyter_server/issues/127


Jupyter Calendar:

.. raw:: html

    <iframe src="https://calendar.google.com/calendar/embed?height=600&amp;wkst=1&amp;bgcolor=%23ffffff&amp;ctz=America%2FLos_Angeles&amp;src=bTNoZWs2OWRhZzczODF1bXQ4a2NqZDc1dTRAZ3JvdXAuY2FsZW5kYXIuZ29vZ2xlLmNvbQ&amp;color=%23F6BF26" style="border:solid 1px #777" width="700" height="500" frameborder="0" scrolling="no"></iframe>